import { FileLoader } from './fileloader';
import { GlTf, GlTfId } from './gltf';
import { LoadingManager } from './loadingmanager';
export declare class GltfAsset {
    /** The JSON part of the asset. */
    gltf: GlTf;
    extensions: any;
    /** Helper for accessing buffer data */
    bufferData: BufferData;
    /** Helper for accessing image data */
    imageData: ImageData;
    constructor(gltf: GlTf, baseUri: string, extensions: any, manager?: LoadingManager);
    /**
     * Fetch the data for a buffer view. Pass in the `bufferView` property of an
     * `Accessor`
     */
    bufferViewData(index: GlTfId): Promise<ArrayBuffer>;
    /** Pre-fetches all buffer and image data. Useful to avoid stalls due to lazy loading. */
    fetchAll(): Promise<void[][]>;
}
export declare class BufferData {
    asset: GltfAsset;
    baseUri: string;
    manager: LoadingManager;
    loader: FileLoader;
    private bufferCache;
    constructor(asset: GltfAsset, baseUri: string, manager: LoadingManager);
    /**
     * Get the buffer data. Triggers a network request if this buffer resides
     * in an external .bin file and is accessed for the first time (cached afterwards).
     * when it's accessed for the first time and `fetchAll` has not been used.
     * To avoid any delays, use `fetchAll` to pre-fetch everything.
     */
    get(index: GlTfId): Promise<ArrayBuffer>;
    /** Pre-fetches all buffer data. */
    fetchAll(): Promise<void[]>;
}
export declare class ImageData {
    asset: GltfAsset;
    baseUri: string;
    manager: LoadingManager;
    private imageCache;
    constructor(asset: GltfAsset, baseUri: string, manager: LoadingManager);
    /**
     * Get the image data. Triggers a network request if image is in an external file
     * and is accessed for the first time (cached afterwards). To avoid any delays,
     * use `fetchAll` to pre-fetch everything.
     */
    get(index: GlTfId): Promise<HTMLImageElement>;
    /** Pre-fetches all image data. */
    fetchAll(): Promise<void[]>;
}
export declare function resolveURL(url: string, path: string): string;
